${ title }

<%inherit file="../base/base.html" /> <%namespace file="../base/base.html" import="header, setup_margin_labels" /> <%block name="title_head"> <%block name="extra_meta"> ${ setup_margin_labels(title) }
${ header(complete_header, title, subtitle, notes) }

${ _("Source") }: | ${ order.source_branch.person.name } | ${ _("Destination") }: | ${ order.destination_branch.person.name }
${ _("Responsible") }: | ${ order.source_responsible.person.name } | ${ _("Responsible") }: | ${ order.destination_responsible.person.name }

# | ${ _("Description") } | ${ _("Quantity") }
% for item in order.get_items():
${ item.sellable.code } | ${ item.sellable.get_description() } | ${ item.quantity }
% endfor
Total: ${ total }

Open: ${ order.open_date.strftime('%x') }
Receival: ${ order.receival_date.strftime('%x') }

${ order.source_responsible.person.name } ${ order.destination_responsible.person.name }